/*
 *	
 * Licensed Materials - Property of IBM
 * 
 * SupportPac CB12 
 * 
 * (c) Copyright IBM Corp. 2013, 2014 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication, or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 */
package genapp.policy;

import java.io.UnsupportedEncodingException;
import java.math.BigInteger;

import com.ibm.cics.server.Channel;
import com.ibm.cics.server.CicsConditionException;
import com.ibm.cics.server.CommAreaHolder;
import com.ibm.cics.server.Container;
import com.ibm.cics.server.Program;
import com.ibm.cics.server.Task;

public class InquirePolicy
{
    // <copyright 
    // notice="cics-lm-java-class" 
    // pids="SupportPac CB12" 
    // years="2013,2014" > 
	static final String COPYRIGHT = "Licensed Materials - Property of IBM SupportPac CB12 (c) Copyright IBM Corp. 2013 2014 All Rights Reserved. US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; 
    // </copyright> 

	//The local CCSID
	private static String LOCAL_CCSID = "cp037";
	
	public static void main(CommAreaHolder CAH)
	{
		byte[] CA = CAH.value;
		Task t=Task.getTask();

		byte retVal = 0;
		String customer;
		try {
			customer = new String(CA, 8, 10, LOCAL_CCSID);

			Channel policyInq = t.createChannel("policyInq");
			Container custContainer = policyInq.createContainer("customer");

			custContainer.put(new BigInteger(customer).toByteArray());

			// Link to the DB2PolicyInquire program, passing the policyInq channel
			Program p = new Program();
			p.setName("IPDB");
			p.link(policyInq);

			Container returnCont = policyInq.getContainer("retVal");
			if(returnCont!=null) {
				retVal =  returnCont.get()[0];
				
				// DB2 code has worked
				if(retVal == 0) {
					for(int i=0;i<5;i++) {
						String policyStr = "          ";
						
						// Get the policy containers which have been returned
						Container policy = policyInq.getContainer("policy"+i);
						if(policy!=null) {
							// pad the policy numbers to be 10 digit long
							policyStr = String.format("%010d", new BigInteger(policy.get()).intValue(), LOCAL_CCSID);
						} else if(i == 0) {
							retVal = 1; // NO DATA
						}
						// store the policy number in the correct part of the CommArea
						byte[] policyNo = policyStr.getBytes(LOCAL_CCSID);
						for(int j=0;j<policyNo.length;j++) {
							CA[18+i*10+j] = policyNo[j];
						}
					}
				}  
			} else {
				retVal = 9;
				System.err.println("NO RETVAL CONTAINER");
			}
		} catch (NumberFormatException nfe) {
			retVal = 1; // NO DATA
			System.err.println("NOT VALID CUSTOMER");
		} catch (Exception cce) {
			System.err.print("Caught CICS Condition Exception: " + cce.getMessage());
			if(cce instanceof CicsConditionException) {
				System.err.println(" Resp2: " + ((CicsConditionException)cce).getRESP2());
			}
			else {
				System.err.println();
			}
			retVal = 8;
		}
		try {
			// convert the byte numerical value to a String encoding for COBOL to display
			byte[] retBytes = Byte.toString(retVal).getBytes(LOCAL_CCSID);
			if(retBytes.length>0) CA[7] = retBytes[0];
		} catch (UnsupportedEncodingException e) {}

		CAH.value = CA;
	}
}
